@@ -423,16 +423,35 @@ book_save_pdf (Book *book, GFile *file, GError **error)
 
     /* Header */
     pdf_printf (writer, "%%PDF-1.3\n");
+
+    /* Comment with binary as recommended so file is treated as binary */
+    pdf_printf (writer, "%%\xe2\xe3\xcf\xd3\n");
   
     /* Catalog */
     catalog_number = pdf_start_object (writer);
     pdf_printf (writer, "%d 0 obj\n", catalog_number);
     pdf_printf (writer, "<<\n");
     pdf_printf (writer, "/Type /Catalog\n");
-    pdf_printf (writer, "/Pages %d 0 R\n", catalog_number + 1);
+    //FIXMEpdf_printf (writer, "/Metadata %d 0 R\n", catalog_number + 1);  
+    pdf_printf (writer, "/Pages %d 0 R\n", catalog_number + 1); //+2
     pdf_printf (writer, ">>\n");
     pdf_printf (writer, "endobj\n");
 
+    /* Metadata */
+    /* FIXME pdf_printf (writer, "\n");
+    number = pdf_start_object (writer);
+    pdf_printf (writer, "%d 0 obj\n", number);
+    pdf_printf (writer, "<<\n");
+    pdf_printf (writer, "/Type /Metadata\n");
+    pdf_printf (writer, "/Subtype /XML\n");
+    pdf_printf (writer, "/Length %d\n", ...);
+    pdf_printf (writer, ">>\n");
+    pdf_printf (writer, "stream\n");
+    // ...
+    pdf_printf (writer, "\n");
+    pdf_printf (writer, "endstream\n");
+    pdf_printf (writer, "endobj\n");*/
+
     /* Pages */
     pdf_printf (writer, "\n");
     pages_number = pdf_start_object (writer);
@@ -454,7 +473,7 @@ book_save_pdf (Book *book, GFile *file, GError **error)
         Page *page;
         GdkPixbuf *image;
         guchar *pixels, *data, *compressed_data;
-        gchar *command;
+        gchar *command, width_buffer[G_ASCII_DTOSTR_BUF_SIZE], height_buffer[G_ASCII_DTOSTR_BUF_SIZE];
         const gchar *color_space, *filter = NULL;
         float page_width, page_height;
 
@@ -620,7 +639,9 @@ book_save_pdf (Book *book, GFile *file, GError **error)
         pdf_printf (writer, "/Type /Page\n");
         pdf_printf (writer, "/Parent %d 0 R\n", pages_number);
         pdf_printf (writer, "/Resources << /XObject << /Im%d %d 0 R >> >>\n", i, number+1);
-        pdf_printf (writer, "/MediaBox [ 0 0 %.2f %.2f ]\n", page_width, page_height);
+        pdf_printf (writer, "/MediaBox [ 0 0 %s %s ]\n",
+                    g_ascii_formatd (width_buffer, sizeof (width_buffer), "%.2f", page_width),
+                    g_ascii_formatd (height_buffer, sizeof (height_buffer), "%.2f", page_height));
         pdf_printf (writer, "/Contents %d 0 R\n", number+2);
         pdf_printf (writer, ">>\n");
         pdf_printf (writer, "endobj\n");
@@ -649,9 +670,12 @@ book_save_pdf (Book *book, GFile *file, GError **error)
 
         /* Page contents */
         command = g_strdup_printf ("q\n"
-                                   "%f 0 0 %f 0 0 cm\n"
+                                   "%s 0 0 %s 0 0 cm\n"
                                    "/Im%d Do\n"
-                                   "Q", page_width, page_height, i);
+                                   "Q",
+                                   g_ascii_formatd (width_buffer, sizeof (width_buffer), "%f", page_width),
+                                   g_ascii_formatd (height_buffer, sizeof (height_buffer), "%f", page_height),
+                                   i);
         pdf_printf (writer, "\n");
         number = pdf_start_object (writer);
         pdf_printf (writer, "%d 0 obj\n", number);
@@ -693,6 +717,7 @@ book_save_pdf (Book *book, GFile *file, GError **error)
     pdf_printf (writer, "/Size %d\n", writer->n_objects);
     pdf_printf (writer, "/Info %d 0 R\n", info_number);
     pdf_printf (writer, "/Root %d 0 R\n", catalog_number);
+    //FIXME: pdf_printf (writer, "/ID [<...> <...>]\n");
     pdf_printf (writer, ">>\n");
     pdf_printf (writer, "startxref\n");
     pdf_printf (writer, "%d\n", xref_offset);
