@@ -651,18 +651,18 @@ get_pixel (Page *page, gint x, gint y, guchar *pixel)
     case TOP_TO_BOTTOM:
         break;
     case BOTTOM_TO_TOP:
-        x = page_get_scan_width (page) - x;
-        y = page_get_scan_height (page) - y;
+        x = page_get_scan_width (page) - x - 1;
+        y = page_get_scan_height (page) - y - 1;
         break;
     case LEFT_TO_RIGHT:
         t = x;
-        x = page_get_scan_width (page) - y;
+        x = page_get_scan_width (page) - y - 1;
         y = t;
         break;
     case RIGHT_TO_LEFT:
         t = x;
         x = y;
-        y = page_get_scan_height (page) - t;
+        y = page_get_scan_height (page) - t - 1;
         break;
     }
 
@@ -721,7 +721,7 @@ page_get_image (Page *page, gboolean apply_crop)
         l = page->priv->crop_x;
         r = l + page->priv->crop_width;
         t = page->priv->crop_y;
-        b = l + page->priv->crop_height;
+        b = t + page->priv->crop_height;
       
         if (l < 0)
             l = 0;
